@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11339 2019-01-15 14:56:17Z Lavender $
+# $Id: __init__.py 11369 2019-02-19 13:16:39Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-01-15 23:56:17 +0900 (週二, 15 一月 2019) $
-# $Revision: 11339 $
+# $Date: 2019-02-19 22:16:39 +0900 (週二, 19 二月 2019) $
+# $Revision: 11369 $
 
 import os
 import sys
@@ -822,9 +822,12 @@ def buildAPIForm(submission, request, apiName, extra={}):
             
             # 隨時接訂單資訊的 URL
             "ServerReplyURL": backUrl[:-1] + reverse("ecpayLogisticReply"), 
-            "ClientReplyURL": returnUrl,               
+            "ClientReplyURL": returnUrl, 
         }
         
+        if mapData['storeType'] == "UNIMARTC2C":
+            data["LogisticsC2CReplyURL"] = returnUrl
+        
         data = OrderedDict(data)
         data = OrderedDict(sorted(data.iteritems()))
 
